@@ -2,13 +2,12 @@
 #' 
 #' @description Performs the pair correlation of molecular brightness (pCOMB) analysis.
 #' @aliases pcomb
-#' @usage pcomb(img, nPoints = 25000, type = "d", dr = 1, w = 100, pcf = TRUE)
+#' @usage pcomb(img, nPoints = 25000, one.col = FALSE, dr = 1, w = 100)
 #' @param img The image to analyze.
 #' @param nPoints The size of the sub-vectors in which the input vectors will be divided. This number must be less than N/2.
-#' @param type By defautl 'd'. The possible values are 'd', 'a' and 'c'
+#' @param one.col By default FALSE. If TRUE the correlation will be performed in the fixed colum mode, else the distance mode.
 #' @param dr Is the distance between the two columns that will be correlated. For a value of deltar = 3, the columns are correlated as follows: (1,4), (2,5), ..., (n-3, n), with n as the last column.
 #' @param w Range value that is used to calculate the brightness in the image.
-#' @param pcf A boolean variable that determines whether the pcf analysis is performed on the brightness carpet or not.
 #' @details With the Pair Correlation of Molecular Brightness (pCOMB) method, one can distinguish between different homo-oligomeric species of the same molecule coexisting in the same microenvironment, while separately and specifically tracking each species' moblity across the cellular compartments. This technique amplifies the signal from the brightest species present and filters the dynamics of the extracted oligomeric population based on arrival time between two locations. This method is suitable for mapping the impact oligomerization on transcription factor dynamics.
 #' The resulting intensity fluctuations, pCF, are transformed into brightness fluctuations using B = (sigma^2)/mean, and the pair correlation analysis is then performed on the brightness fluctuations along the line scan , at a distance (delta(r)).
 #' 
@@ -16,7 +15,7 @@
 #' @export
 #' @importFrom stats var
 #' @return A list containing the Brightness Carpet and the Pair Correlation of that carpet
-#' @author Raul Pinto Camara.
+#' @author Raúl Pinto Cámara.
 #' 
 #' @seealso \code{\link{fcs}, \link{pcf}}
 #' 
@@ -44,7 +43,7 @@
 #' cex.lab = 1.2, cex.main = 1.2, cex.axis = 1)
 #' }
 
-pcomb <- function(img, nPoints = 25000, type = "d", dr = 1, w = 100, pcf = TRUE){
+pcomb <- function(img, nPoints = 25000, one.col = FALSE, dr = 1, w = 100){
   di <- dim(img)
   if(length(di) != 2){
     stop("'img' must be two dimensional")
@@ -52,11 +51,14 @@ pcomb <- function(img, nPoints = 25000, type = "d", dr = 1, w = 100, pcf = TRUE)
   if((nPoints*2) > di[2]){
     stop("'nPoints' must be less than the length of the second dimension of image / 2")
   }
-  if(tolower(type) != "d" && tolower(type) != "c" && tolower(type) != "a"){
-    stop("'type' must be 'd' or 'c' or 'a'")
-  }
-  if(dr < 0 || dr > di[1]){
-    stop(paste("'dr' must be dr >= 0 and dr <= ", di[1], sep = ""))
+  if(one.col){
+    if(dr <= 0 || dr > di[1]){
+      stop(paste("'dr' must be dr > 0 and dr <= ", di[1], sep = ""))
+    }
+  } else{
+    if(dr < 0 || dr > di[1]){
+      stop(paste("'dr' must be dr >= 0 and dr <= ", di[1], sep = ""))
+    }
   }
   if(w < 2){
     stop("w must be at least w = 2")
@@ -66,8 +68,6 @@ pcomb <- function(img, nPoints = 25000, type = "d", dr = 1, w = 100, pcf = TRUE)
     pB[,i] <- apply(img[,i:(i+w-1)], MARGIN = 1, var)/apply(img[,i:(i+w-1)], MARGIN = 1, mean)
   }
   pC <- NULL
-  if(pcf){
-    pC <- pcf(pB, nPoints, type, dr)
-  }
-  return(list("BCarpet" = pB, "pComb" = pC))
+  pC <- pcf(pB, nPoints, one.col, dr)
+  return(pC)
 }
\ No newline at end of file
